@@ -470,11 +470,21 @@ const powerpc_cpu::instr_info_t powerpc_cpu::powerpc_ii_table[] = {
 	  PPC_I(FNMSUBS),
 	  A_form, 59, 30, CFLOW_NORMAL
 	},
+	{ "fres",
+	  EXECUTE_FP_ARITH(double, fres, RD, RB, NONE, NONE, RC_BIT_G, true),
+	  PPC_I(FRES),
+	  A_form, 59, 24, CFLOW_NORMAL
+	},
 	{ "frsp",
 	  EXECUTE_1(fp_round, RC_BIT_G),
 	  PPC_I(FRSP),
 	  X_form, 63, 12, CFLOW_NORMAL
 	},
+	{ "frsqrte",
+	  EXECUTE_FP_ARITH(double, frsqrte, RD, RB, NONE, NONE, RC_BIT_G, true),
+	  PPC_I(FRSQRTE),
+	  A_form, 63, 26, CFLOW_NORMAL
+	},
 	{ "fsel",
 	  EXECUTE_FP_ARITH(double, fsel, RD, RA, RC, RB, RC_BIT_G, false),
 	  PPC_I(FSEL),
@@ -1551,7 +1561,7 @@ const powerpc_cpu::instr_info_t powerpc_cpu::powerpc_ii_table[] = {
 	  VX_form, 4, 132, CFLOW_NORMAL
 	},
 	{ "vrsqrtefp",
-	  EXECUTE_VECTOR_ARITH(frsqrt, V4SF, NONE, V4SF, NONE),
+	  EXECUTE_VECTOR_ARITH(frsqrte, V4SF, NONE, V4SF, NONE),
 	  PPC_I(VRSQRTEFP),
 	  VX_form, 4, 330, CFLOW_NORMAL
 	},
